Documentation
¶
Index ¶
Constants ¶
const ( // ApplicationKey is the key kind for ARI Application resources. ApplicationKey = "application" // BridgeKey is the key kind for the ARI Bridge resources. BridgeKey = "bridge" // ChannelKey is the key kind for the ARI Channel resource ChannelKey = "channel" // DeviceStateKey is the key kind for the ARI DeviceState resource DeviceStateKey = "devicestate" // EndpointKey is the key kind for the ARI Endpoint resource EndpointKey = "endpoint" // LiveRecordingKey is the key kind for the ARI LiveRecording resource LiveRecordingKey = "liverecording" // LoggingKey is the key kind for the ARI Logging resource LoggingKey = "logging" // MailboxKey is the key kind for the ARI Mailbox resource MailboxKey = "mailbox" // ModuleKey is the key kind for the ARI Module resource ModuleKey = "module" // PlaybackKey is the key kind for the ARI Playback resource PlaybackKey = "playback" // SoundKey is the key kind for the ARI Sound resource SoundKey = "sound" // StoredRecordingKey is the key kind for the ARI StoredRecording resource StoredRecordingKey = "storedrecording" // VariableKey is the key kind for the ARI Asterisk Variable resource VariableKey = "variable" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Key ¶
type Key struct {
Kind string `json:"kind,omitempty"`
ID string `json:"id,omitempty"`
Node string `json:"node,omitempty"`
App string `json:"app,omitempty"`
}
func NewKey ¶
func NewKey(kind string, id string, opts ...KeyOptionFunc) *Key
NewKey builds a new key given the kind, identifier, and any optional arguments.
type KeyOptionFunc ¶
KeyOptionFunc is a functional argument alias for providing options for ARI keys
func WithApp ¶
func WithApp(app string) KeyOptionFunc
WithApp sets the given node identifier on the key.
func WithNode ¶
func WithNode(node string) KeyOptionFunc
WithNode sets the given node identifier on the key.
Click to show internal directories.
Click to hide internal directories.